<?php
// Copyright (C) <2015-present>  <it-novum GmbH>
//
// This file is licensed under the terms of the openITCOCKPIT Enterprise Edition license agreement.
// The license agreement and license key were sent with the order confirmation.


namespace DB2Module\Lib\InitialDatabase;

use App\Model\Table\CommandsTable;
use App\Model\Table\ServicetemplategroupsTable;
use App\Model\Table\ServicetemplatesTable;
use App\Model\Table\WizardAssignmentsTable;
use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package DB2Module\Lib\InitialDatabase
 */
class TemplateImport extends Importer {
    /**
     * @var CommandsTable
     */
    private $CommandsTable;

    /**
     * @var ServicetemplatesTable
     */
    private $ServicetemplatesTable;

    /**
     * @var WizardAssignmentsTable
     */
    private $WizardAssignmentsTable;

    /**
     * @var array
     */
    private $mapping = [];

    /**
     * TemplateImport constructor.
     * @param CommandsTable $CommandsTable
     * @param ServicetemplatesTable $ServicetemplatesTable
     * @param WizardAssignmentsTable $WizardAssignmentsTable
     */
    public function __construct(CommandsTable $CommandsTable, ServicetemplatesTable $ServicetemplatesTable, WizardAssignmentsTable $WizardAssignmentsTable) {
        $this->CommandsTable = $CommandsTable;
        $this->ServicetemplatesTable = $ServicetemplatesTable;
        $this->WizardAssignmentsTable = $WizardAssignmentsTable;
    }

    /**
     * @return bool
     */
    public function import() {
        $data = $this->getData();
        foreach ($data['Commands'] as $command) {
            if (isset($command['uuid']) && !$this->CommandsTable->existsByUuid($command['uuid'])) {
                $entity = $this->CommandsTable->newEntity($command);
                $this->CommandsTable->save($entity);
            }
        }
        $this->mapping['servicetemplates'] = [];

        foreach ($data['Servicetemplates'] as $servicetemplate) {
            if ($this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                $existingServicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplate['uuid']);
                $this->mapping['servicetemplates'][$servicetemplate['uuid']] = $existingServicetemplate['Servicetemplate']['id'];
                //skip current template if it already exists
                continue;
            }
            if (isset($servicetemplate['uuid']) && !$this->ServicetemplatesTable->existsByUuid($servicetemplate['uuid'])) {
                if (isset($servicetemplate['command_id']) && $this->CommandsTable->existsByUuid($servicetemplate['command_id'])) {
                    $command = $this->CommandsTable->getCommandByUuid($servicetemplate['command_id'], true, false)[0];
                    $servicetemplate['command_id'] = $command['id'];
                    if (!empty($servicetemplate['servicetemplatecommandargumentvalues']) && !empty($command['commandarguments'])) {
                        foreach ($servicetemplate['servicetemplatecommandargumentvalues'] as $templateArgumentKey => $templateArgumentValue) {
                            $servicetemplate['servicetemplatecommandargumentvalues'][$templateArgumentKey] = [
                                'commandargument_id' => $this->getCommandArgumentIdByName($templateArgumentValue['commandargument_id'], $command['commandarguments']),
                                'value'              => $templateArgumentValue['value'],
                            ];
                        }
                    }
                    $entity = $this->ServicetemplatesTable->newEntity($servicetemplate);
                    $this->ServicetemplatesTable->save($entity);
                    $this->mapping['servicetemplates'][$entity->get('uuid')] = $entity->get('id');
                }
            }
        }

        if (!empty($data['Wizardassignment'])) {
            $wizardassignmentEntity['uuid'] = $data['Wizardassignment']['uuid'];
            $wizardassignmentEntity['type_id'] = $data['Wizardassignment']['type_id'];
            foreach ($data['Wizardassignment']['servicetemplates']['_ids'] as $servicetemplateUuid) {
                $servicetemplate = $this->ServicetemplatesTable->getServicetemplateByUuid($servicetemplateUuid);
                if (isset($servicetemplate['Servicetemplate']) && isset($servicetemplate['Servicetemplate']['id'])) {
                    $wizardassignmentEntity['servicetemplates']['_ids'][] = $servicetemplate['Servicetemplate']['id'];
                }
            }
            if (!$this->WizardAssignmentsTable->existsByUuidAndTypeId($wizardassignmentEntity['uuid'], $wizardassignmentEntity['type_id'])) {
                $entity = $this->WizardAssignmentsTable->newEntity($wizardassignmentEntity);
                $this->WizardAssignmentsTable->save($entity);
            } else {
                $existingAssignment = $this->WizardAssignmentsTable->getWizardByUuidForEdit($wizardassignmentEntity['uuid']);
                foreach (array_diff($wizardassignmentEntity['servicetemplates']['_ids'], $existingAssignment['servicetemplates']['_ids']) as $missingServicetemplateId) {
                    $existingAssignment['servicetemplates']['_ids'][] = $missingServicetemplateId;
                }
                $entity = $this->WizardAssignmentsTable->get($existingAssignment['id']);
                $entity = $this->WizardAssignmentsTable->patchEntity($entity, $existingAssignment);
                $this->WizardAssignmentsTable->save($entity);
            }
        }
        return true;
    }

    /**
     * @return array
     */
    public function getData() {
        return [
            'Commands'         => $this->getCommandsData(),
            'Servicetemplates' => $this->getServicetemplatesData(),
            'Wizardassignment' => $this->getWizardAssignmentData()
        ];
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            0 => [
                'name'             => 'check_db2_health',
                'command_line'     => '$USER1$/check_db2_health --hostname=$HOSTADDRESS$ --database=$ARG1$ --port=$ARG2$ --username=$_HOSTDBUSER$ --password=$_HOSTDBPASS$ --warning=$ARG3$ --critical=$ARG4$ --mode=$ARG5$',
                'command_type'     => '1',
                'human_args'       => null,
                'uuid'             => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'description'      => '',
                'commandarguments' => [
                    0 => [
                        'name'       => '$ARG1$',
                        'human_name' => 'Database',
                    ],
                    1 => [
                        'name'       => '$ARG2$',
                        'human_name' => 'Port',
                    ],
                    2 => [
                        'name'       => '$ARG3$',
                        'human_name' => 'Warning',
                    ],
                    3 => [
                        'name'       => '$ARG4$',
                        'human_name' => 'Critical',
                    ],
                    4 => [
                        'name'       => '$ARG5$',
                        'human_name' => 'Mode',
                    ]
                ]
            ]
        ];
        return $data;
    }


    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0 => [
                'uuid'                                      => '3140eea9-93b7-41a7-b1a9-6dfb8b60fc62',
                'template_name'                             => 'DB2_CONNECTION_TIME',
                'name'                                      => 'Connection-Time DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '2',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '5',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'connection-time',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            1 => [
                'uuid'                                      => '0f6162f4-3ede-4731-828f-2f4c27d01187',
                'template_name'                             => 'DB2_CONNECTED_USERS',
                'name'                                      => 'Connected-Users DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '100',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '150',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'connected-users',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            2 => [
                'uuid'                                      => '02044e2c-8b9f-4798-8706-bf8312407c78',
                'template_name'                             => 'DB2_DATABASE_USAGE',
                'name'                                      => 'Database-Usage DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '90',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '95',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'database-usage',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            3 => [
                'uuid'                                      => 'd5fa8cb4-081f-4f96-abf2-345454760a0e',
                'template_name'                             => 'DB2_TABLESPACE_USAGE',
                'name'                                      => 'Tablespace-Usage DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '90',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '95',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'tablespace-usage',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            4 => [
                'uuid'                                      => 'b7f8c9e8-f915-4b5e-8fdc-2d6de52931eb',
                'template_name'                             => 'DB2_INDEX_USAGE',
                'name'                                      => 'Index-Usage DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '90',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '95',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'index-usage',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            5 => [
                'uuid'                                      => '7e7406e0-7c73-4bfb-88ec-af90aade4ed0',
                'template_name'                             => 'DB2_LOG_UTILIZATION',
                'name'                                      => 'Log-Utilization DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '90',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '95',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'log-utilization',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ],
            6 => [
                'uuid'                                      => 'd836a1b9-1463-450b-93c8-72fca4f18706',
                'template_name'                             => 'DB2_BACKUP_AGE',
                'name'                                      => 'Backup-Age DBNAME',
                'container_id'                              => '1',
                'servicetemplatetype_id'                    => '1',
                'check_period_id'                           => '1',
                'notify_period_id'                          => '1',
                'description'                               => '',
                'command_id'                                => '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                'check_command_args'                        => '',
                'checkcommand_info'                         => '',
                'eventhandler_command_id'                   => '0',
                'timeperiod_id'                             => null,
                'check_interval'                            => '300',
                'retry_interval'                            => '60',
                'max_check_attempts'                        => '3',
                'first_notification_delay'                  => '0',
                'notification_interval'                     => '7200',
                'notify_on_warning'                         => '1',
                'notify_on_unknown'                         => '1',
                'notify_on_critical'                        => '1',
                'notify_on_recovery'                        => '1',
                'notify_on_flapping'                        => '0',
                'notify_on_downtime'                        => '0',
                'flap_detection_enabled'                    => '0',
                'flap_detection_on_ok'                      => '0',
                'flap_detection_on_warning'                 => '0',
                'flap_detection_on_unknown'                 => '0',
                'flap_detection_on_critical'                => '0',
                'low_flap_threshold'                        => '0',
                'high_flap_threshold'                       => '0',
                'process_performance_data'                  => '1',
                'freshness_checks_enabled'                  => '0',
                'freshness_threshold'                       => '3600',
                'passive_checks_enabled'                    => '1',
                'event_handler_enabled'                     => '0',
                'active_checks_enabled'                     => '1',
                'retain_status_information'                 => '0',
                'retain_nonstatus_information'              => '0',
                'notifications_enabled'                     => '1',
                'notes'                                     => '',
                'priority'                                  => '1',
                'tags'                                      => '',
                'service_url'                               => '',
                'is_volatile'                               => '0',
                'check_freshness'                           => '0',
                'created'                                   => '2021-06-09 09:01:35',
                'modified'                                  => '2021-06-09 09:01:35',
                'servicetemplateeventcommandargumentvalues' => [],
                'servicetemplatecommandargumentvalues'      => [
                    0 => [
                        'commandargument_id' => '$ARG1$',
                        'value'              => 'DBNAME',
                    ],
                    1 => [
                        'commandargument_id' => '$ARG2$',
                        'value'              => 'XXXXX',
                    ],
                    2 => [
                        'commandargument_id' => '$ARG3$',
                        'value'              => '24',
                    ],
                    3 => [
                        'commandargument_id' => '$ARG4$',
                        'value'              => '48',
                    ],
                    4 => [
                        'commandargument_id' => '$ARG5$',
                        'value'              => 'last-backup',
                    ],
                ],
                'customvariables'                           => [],
                'servicegroups'                             => [],
                'contactgroups'                             => [],
                'contacts'                                  => [],
            ]
        ];
        return $data;
    }


    /**
     * @param string $name
     * @param array $commandarguments
     * @return bool|mixed
     */
    public function getCommandArgumentIdByName(string $name, array $commandarguments) {
        foreach ($commandarguments as $commandargument) {
            if (isset($commandargument['name']) && $commandargument['name'] === $name) {
                return $commandargument['id'];
            }
        }
        return false;
    }

    /**
     * @return array
     */
    public function getWizardAssignmentData() {
        $data = [

            'uuid'             => 'b5d9df20-bd54-4ef6-9b76-c1fd60a574e9',
            'type_id'          => 'db2',
            'servicetemplates' => [
                '_ids' => [
                    '3140eea9-93b7-41a7-b1a9-6dfb8b60fc62',
                    '91df2d5d-d3dd-4a1b-b363-880f29df7398',
                    '0f6162f4-3ede-4731-828f-2f4c27d01187',
                    '02044e2c-8b9f-4798-8706-bf8312407c78',
                    'd5fa8cb4-081f-4f96-abf2-345454760a0e',
                    'b7f8c9e8-f915-4b5e-8fdc-2d6de52931eb',
                    '7e7406e0-7c73-4bfb-88ec-af90aade4ed0',
                    'd836a1b9-1463-450b-93c8-72fca4f18706'
                ]
            ]
        ];
        return $data;
    }
}
